@@ -2,7 +2,7 @@
 # test to check that -m parameter checking is right.
 set -e
 [ "`./dsh -M -recho -m a,b,c,c,d `" = "\
-d: d
-c: c
+a: a
 b: b
-a: a" ]; 
+c: c
+d: d" ]; 
